@@ -14,17 +14,21 @@ class OnDel(events.Handler):
 class OnChange(events.Handler):
     event_type = OnChangeEvent
 
-class OnGetDescriptor(descriptors.Handler):
+class OnGetHandler(descriptors.Handler):
+    __alias__ = 'on_get'
     default = OnGet
 
-class OnSetDescriptor(descriptors.Handler):
+class OnSetHandler(descriptors.Handler):
+    __alias__ = 'on_set'
     default = OnSet
 
-class OnDelDescriptor(descriptors.Handler):
+class OnDelHandler(descriptors.Handler):
+    __alias__ = 'on_del'
     default = OnDel
 
-class OnChangeDescriptor(descriptors.Handler):
+class OnChangeHandler(descriptors.Handler):
+    __alias__ = 'on_change'
     default = OnChange
 
 
-Subject = events.Subject(OnGetDescriptor, OnSetDescriptor, OnDelDescriptor, OnChangeDescriptor)
+Subject = events.Subject(OnGetHandler, OnSetHandler, OnDelHandler, OnChangeHandler)
