@@ -1,15 +1,15 @@
 # -*- coding: utf8 -*-
 from .named import Named
 from .. import events
+from .value import Value
 
 
 class Handler(events.Handler, Named):
     default = events.Handler
-    def set_default(self, instance, alias):
-        if self.is_set(instance, alias): return False
-        handler = self.default(condition=self.condition)
-        self.set(instance, alias, handler)
-        return True
+    class ValueType(Value):
+        def init_value(self, value):
+            super(type(self), self).init_value(None)
+            self.set(value())
 
     def __hash__(self):
         return id(self)
